#
# spec file for package python-pyghmi
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-pyghmi
Version:        1.0.4
Release:        1.1
Summary:        Python General Hardware Management Initiative (IPMI and others)
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            http://xcat.sf.net/
Source:         https://pypi.python.org/packages/b2/72/47809f0059af26b3de70f8242ab56ea8e39186535bcaa2f6e3144f57b08c/pyghmi-%{version}.tar.gz
BuildRequires:  python-devel
BuildRequires:  python-pbr
BuildRequires:  python-python-subunit
BuildRequires:  python-testrepository
Requires:       python-pbr
Requires:       python-pycrypto >= 2.6
%if 0%{?suse_version}
# libvirt-python is only needed for bin/virshbmc
Recommends:     libvirt-python >= 1.2.5
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
This is a pure python implementation of IPMI protocol.

%prep
%setup -q -n pyghmi-%{version}

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

%check
testr init && testr run --parallel

%files
%defattr(-,root,root,-)
%doc ChangeLog README LICENSE AUTHORS
%{_bindir}/pyghmicons
%{_bindir}/pyghmiutil
%{_bindir}/virshbmc
%{python_sitelib}/*

%changelog
* Wed May 11 2016 dmueller@suse.com
-  update to 1.0.4:
  * Allows BMCs to configure the event loop timeout
  * Add Hardware inventory from Lenovo Agentless
  * Fix IPMI server functionality
  * Add disk inventory when possible from Lenovo IMM
  * Cope with empty agentless fields
  * Briefly cache adapter data
  * Add 'Trusted IMM' to IMM inventory
  * Passthrough errors when not sent by BMC in MegaRAC
  * Change strategy to identify IMM
  * Do not hook generic vendor identifier
  * Add support for IPv4-only environments
  * Add system X firmware information
  * Be apathetic about endianness of SOL port number
  * Fix get_health with a NextScale FPC
  * Implement MegaRAC IPv6 SNMP destinations
  * Do not warn on nearly full SEL
  * Fix use of weakref.ref
  * Fix cyclic references in SDR
  * Discard reference when no longer needed
  * Remove a cyclical reference in Lenovo OEM
  * Remove event related memory leak
  * Change DIMM serial to show 0 padded hexadecimal
  * Fix UUID padding problem
  * Determine speed from clock by formula
  * Avoid stall waiting on incommand
  * Implement detach media
  * Allow skipping retrieval of gateway mac addresses
  * Provide attach remote media function
  * Have ipv6 addresses always be represented as list
  * Add support for OEM command for IPv6 address fetch
  * Add a new README
  * Change graphical console launcher to use base64 encoding
  * Add support for TS graphical console fetching
  * Rework wait behavior
  * Fix synchronous logon premature exit
* Sat Jul 25 2015 seife+obs@b1-systems.com
- fix non-SUSE build by conditionalizing "Recommends" tag
* Wed Jun 17 2015 tbechtold@suse.com
- update to 0.8.0:
  * Provide interface for decoding PET alerts
  * Handle unknown entity ids
  * Tolerate alternative return code for FRU size
  * Remove libvirt from requirements
  * Provide access to get/set community string
  * Add serial field from SPD
  * Implement OEM Inventory components
  * Report/Configure LAN alert destinations
  * Implement Thinkserver OEM SEL decode
  * Fix behavior with some Lenovo Thinkservers
  * Only conditionally delete fields from event
  * Fix python2.6 usage of unpack_from
  * For unspecified sensors use None as the component
  * Update decode of HDD OEM events for Lenovo
  * Declare one sort of 'non-redundancy' ok
  * Add OEM event fixup
  * Change event text based on assertion/deassertion
  * Tolerate missing UUID
  * Rename 'entity' to 'component'
  * Leave numbers intact
  * Flesh out and rework some sensor descriptions
  * Break out of FRU read if zero data returned
  * Fix time correction code
  * Decrease severity of 'Disabled' presence
  * Rename description field and split data out
  * Implement event log retrieval from BMCs
* Wed May  6 2015 tbechtold@suse.com
- update to 0.7.1:
  * Add system UUID to inventory
  * Fix parsing of 6bit ascii
  * Clean up strings from FRU
  * Add function to fetch a specific items inventory
  * Tolerate errors in 'extra' fields
  * Create framework for OEM extensions
  * Implement FRU inventory
  * Try setting optional byte in set user acess
  * Reduce cost of packet transmit
  * Ignore packet overrun in RAKP2 and RAKP4
  * Streamline and simplify IO Polling
  * Reduce severity of a non-redundant state
  * Add missing generic discrete codes
  * Fix exceptions on sdr read
  * Move packet queue into IO thread
  * Fix needless retries due to misdirected packets
  * Handle concurrent session requests
  * Added a BMC (IPMI) frontend for virsh
  * Add a "--port" option to fakebmc
  * Correct delay_xmit behavior
  * Rework IO Worker thread behavior
  * Correct redundant timedout calls in recursion
  * Assign code to timeout behavior
  * Gracefully handle error while acking SOL
  * add more commands
  * Enhance IpmiException to carry IPMI codenumber
  * Allow request for single sensor by name
  * Expose sensor description data
  * Implement server side IPMI protocol
  * Check for IPMIPASSWORD env var in pyghmiutil
  * Run pep8 on files in bin/
  * Provide access to chassis identify
  * Implement retrieval of uefi flag in boot devs
  * Recover from kill() while in command
  * Remove overly aggressive packet processing
  * Handle custom keepalive modifications on the fly
  * Avoid exception on close
  * Avoid recursing between keepalive and raw_command
  * Work toward Python 3.4 support and testing
  * Fix IO worker tolerance of errors
  * Force non-numeric for compact sensor records
  * Change to name-only lookups in RAKP
  * Handle non-linear and unrecognized linearizations
  * Add 'persistent' to return dict of get_bootdev
  * Raise IpmiException on an error setting/getting the boot device
  * Use get() to avoid KeyError on get_bootdev()
  * Reduce severity of generic discrete assert to 'Ok'
* Thu Jun 26 2014 dmueller@suse.com
- update to 0.6.15:
  * Tolerate more privilege degradation scenarios
  * Fix concurrent raw_command calls to Session
  * Don't defer custom keepalive expiry on all payloads
  * Fix infinitely recursing custom keepalives
  * Fix IPv4 operations where v6only behavior is default
  * Fix pyghmicons script crash on idle
  * Added password file support
  * Correct pool usage count on failed login
  * Correct console behavior when open session fails
  * Deregister timeout on broken
  * Correct ignoring socket when inappropriate
  * Fix coping with incoming packet in incomplete state
  * Fix unregister_keepalive when no keepalives registered
  * Fix attribute error on particularly bad connections
  * Handle packet loss correctly in logout/logon
  * Avoid looping select() on sockets repeatedly
  * Correct return value of set_bootdev
  * Install scripts as well as library
  * Remove references to custom keepalives on logout
  * Slow down to chunk-wise retrieval of SDR as needed
  * Implement function to check SOL payload as keepalive
  * Avoid zombie sessions corrupting living sessions
  * Do not reuse a session that is not logged
  * Break session objects on keepalive failures
  * Use multiple sockets instead of one
  * General cleanup of session
  * Correct check for _sdr in command
  * Clean up command.py
  * Correct mistakes in constants
  * Correct sensor offset for byte 5 state values
  * Fix mass thread initialization of sessions
  * Add sensor information from IPMI 2.0 rev 1.1
  * Add optical and bios aliases for boot devices
  * Auto degrade sessions to operator when admin is forbidden
  * Add more missing sensor specific event information
  * Add version change sensor information
  * Gracefully flag unrecognized discrete sensor states
  * Add discrete states for event log status sensors
  * Allow pyghmi to send break over IPMI SOL
  * Switch from PyCrypto HMAC to standard python hmac
  * Tolerate unicode strings as username and password
  * Fix missing delay_xmit argument breaking power wait requests
  * Fix race condition in requesting delays
  * Fix race condition on sending data
* Fri Feb 14 2014 speilicke@suse.com
- Run testr directly
* Fri Sep 27 2013 dmueller@suse.com
- Initial package (0.5.8)
